<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="yes" indent="yes"/>

<xsl:template match="/">
<scene>

  <!-- Materialien -->
  <xsl:for-each select="/BlendFile/Material">
    <shader type="generic" name="{ID/Variable[@Name='name[24]']/Data/@Value">
      <attributes>
        <color r="{Variable[@Name='r']/Data/@Value}" g="{Variable[@Name='g']/Data/@Value}" b="{Variable[@Name='b']/Data/@Value}" />
        <specular r="{Variable[@Name='specr']/Data/@Value}" g="{Variable[@Name='specg']/Data/@Value}" b="{Variable[@Name='specb']/Data/@Value}" />
        <reflected r="{Variable[@Name='mirr']/Data/@Value}" g="{Variable[@Name='mirg']/Data/@Value}" b="{Variable[@Name='mirb']/Data/@Value}" />
        <transmited r="{Variable[@Name='ambr']/Data/@Value}" g="{Variable[@Name='ambg']/Data/@Value}" b="{Variable[@Name='ambb']/Data/@Value}" />
      </attributes>
    </shader>
  </xsl:for-each>

  <!-- hier mesh konvertieren -->
  <xsl:for-each select="/BlendFile/Mesh">
    <object name="{ID/Variable[@Name='name[24]']/Data/@Value" shader_name="blanco">
      <attributes>
      </attributes>
      <mesh>
        <points>
          <xsl:for-each select="MVert">
            <p x="{Variable[@Name='co[3]']/Data[1]/@Value}"
               y="{Variable[@Name='co[3]']/Data[2]/@Value}"
               z="{Variable[@Name='co[3]']/Data[3]/@Value}" />
          </xsl:for-each>
        </points>
        <faces>
          <xsl:for-each select="MFace">
            <f a="0" b="1" c="2" u_a="0.0" v_a="0.0" u_b="1.0" v_b="0.0" u_c="1.0" v_c="1.0" />
            <f a="2" b="3" c="0" u_a="1.0" v_a="1.0" u_b="0.0" v_b="1.0" u_c="0.0" v_c="0.0" />
          </xsl:for-each>
        </faces>
      </mesh>
    </object>
  </xsl:for-each>

  <!-- Licht -->
  <xsl:for-each select="/BlendFile/Lamp">
    <xsl:variable name="id"><xsl:value-of select="@ID"/></xsl:variable>
    <light type="softlight" name="{ID/Variable[@Name='name[24]']/Data/@Value" power="2.0" res="100" radius="5" bias="0.2">
      <from x="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[1]/@Value}"
            y="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[2]/@Value}"
            z="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[3]/@Value}" />
      <color r="{Variable[@Name='r']/Data/@Value}" g="{Variable[@Name='g']/Data/@Value}" b="{Variable[@Name='b']/Data/@Value}" />
    </light>
  </xsl:for-each>

  <!-- Kamera -->
  <xsl:for-each select="/BlendFile/Camera">
    <xsl:variable name="id"><xsl:value-of select="@ID"/></xsl:variable>
    <camera name="{ID/Variable[@Name='name[24]']/Data/@Value" resx="640" resy="480" focal="0.7" >
      <from x="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[1]/@Value}" 
            y="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[2]/@Value}"
            z="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='loc[3]']/Data[3]/@Value}" />
      <to x="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='dloc[3]']/Data[1]/@Value}" 
          y="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='dloc[3]']/Data[2]/@Value}" 
          z="{/BlendFile/Object[Variable/Data/@Value=$id]/Variable[@Name='dloc[3]']/Data[3]/@Value}" />
      <up x="-1.9" y="0" z="2" />
    </camera>
  </xsl:for-each>

  <!-- Render -->
  <xsl:for-each select="/BlendFile/Scene">
    <render camera_name="{/BlendFile/Camera/ID/Variable[@Name='name[24]']/Data/@Value}" samples="5" bias="0.3">
    </render>
  </xsl:for-each>


</scene>
</xsl:template>
</xsl:stylesheet>
